==================
Important History
==================

-1.3.4 bug fixes for the dutch language
- 1.3.3 fixed bug in google translate

- 1.2.5: added support for the DeepL translator
- 1.2.4: added support for the QCRI translator
- 1.2.1: added support for the yandex translator
- 1.1.9: fixed bug in requests
- 1.1.5: added language detection
- 1.1.3: added support for mymemory
- 1.0.4: added support for pons
- 1.0.2: added support for linguee
- 1.0.0: added support for google translate
